from django import forms
from cmsplugin_fancybox.models import FancyBoxPlugin
from tinymce.widgets import TinyMCE

class FancyBoxRichTextPluginForm(forms.ModelForm):
    popup_text = forms.CharField(widget=TinyMCE())
    class Meta:
        model = FancyBoxPlugin
        exclude = ('target_image', 'target_image_height', 'target_image_width', 'target_image_title',)
        
class FancyBoxImagePluginForm(forms.ModelForm):
    class Meta:
        model = FancyBoxPlugin
        exclude = ('popup_text',)



from django.utils.translation import ugettext_lazy as _
from django.conf import settings
from django.db import models
from cms.models import CMSPlugin
from cms.models.fields import PageField
from cms.models.fields import PlaceholderField
from filer.fields.image import FilerImageField
    
class FancyBoxPlugin(CMSPlugin):
    link_text = models.CharField(max_length=255, blank=True, null=True)
    
    link_image = FilerImageField(null=True, blank=True, default=None, related_name='fancyboxplugin_set_link_image')
    link_image_height = models.PositiveIntegerField(blank=True, null=True)
    link_image_width = models.PositiveIntegerField(blank=True, null=True)
    
    target_image = FilerImageField(null=True, related_name='fancyboxplugin_set_target_image')
    target_image_height = models.PositiveIntegerField(blank=True, null=True)
    target_image_width = models.PositiveIntegerField(blank=True, null=True)
    target_image_title = models.CharField(max_length=255, blank=True, null=True)
    
    popup_text = models.TextField(null=True)
    
    def get_target_image_dimensions(self):
        height = self.target_image_height or self.target_image.height
        width = self.target_image_width or self.target_image.width
        return '%sx%s' % (width, height)
    
    def get_link_image_dimensions(self):
        height = self.link_image_height or self.link_image.height
        width = self.link_image_width or self.link_image.width
        return '%sx%s' % (width, height)

    def clean(self):
        from django.core.exceptions import ValidationError
        # Make sure that either image or link_text are set
        if (not self.link_image and not self.link_text):
            raise ValidationError(_('Either an image or link text must be selected.'))




from cms.plugin_pool import plugin_pool
from cms.plugin_base import CMSPluginBase
from django.utils.translation import ugettext_lazy as _
from django.conf import settings
from django.core.urlresolvers import reverse
from cmsplugin_fancybox.models import FancyBoxPlugin
from cmsplugin_fancybox.forms import FancyBoxImagePluginForm, FancyBoxRichTextPluginForm

class CMSFancyBoxImagePlugin(CMSPluginBase):
    model = FancyBoxPlugin
    form = FancyBoxImagePluginForm
    name = _("Fancybox Image Popup")
    render_template = "cmsplugin_fancybox/cmsplugin_fancybox_image.html"

    def render(self, context, instance, placeholder):
        context.update({
            'instance': instance,
        })
        return context
        

class CMSFancyBoxRichTextPlugin(CMSPluginBase):
    model = FancyBoxPlugin
    form = FancyBoxRichTextPluginForm
    name = _("Fancybox Rich Text Popup")
    render_template = "cmsplugin_fancybox/cmsplugin_fancybox_richtext.html"

    def render(self, context, instance, placeholder):
        context.update({
            'instance': instance,
        })
        return context
        

plugin_pool.register_plugin(CMSFancyBoxImagePlugin)
plugin_pool.register_plugin(CMSFancyBoxRichTextPlugin)



from setuptools import setup, find_packages
import os

version = __import__('cmsplugin_fancybox').__version__

install_requires = [
    'setuptools',
    'django',
    'django-cms',
    'django-filer',
    'django-tinymce',
]

setup(
    name = "django-cms-fancybox",
    version = version,
    url = 'http://github.com/megamark16/django-cms-fancybox',
    license = 'BSD',
    platforms=['OS Independent'],
    description = "A fancybox extension for Django CMS",
    author = "Mark Ransom",
    author_email = 'megamark16@gmail.com',
    packages=find_packages(),
    install_requires = install_requires,
    include_package_data=True,
    zip_safe=False,
    classifiers = [
        'Development Status :: 4 - Beta',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
    ],
    package_dir={
        'cmsplugin_fancybox': 'cmsplugin_fancybox',
    },
)
